@@ -9,7 +9,7 @@ from getmac import get_mac_address as gma
 def inference(img_path,lang,model_rec,model_det):
     try:
         macadd=gma()
-        uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34"]
+        uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34","1c:69:7a:ae:44:32"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
             ocr = PaddleOCR(use_angle_cls=True,lang=lang,use_gpu=False,rec_model_dir=model_rec)
